#!/bin/bash
# homepage: http://id3lib.sourceforge.net
# depends : zlib
# script  : til (rob.til.freedman~AT~gmail.com)
# set -x
SOURCE_URL='http://heanet.dl.sourceforge.net/sourceforge/easytag'
PATCH_FILE='patch_id3lib_3.8.3_UTF16_writing_bug.diff'

# build variables
NAME='id3lib'
VERSION='3.8.3'
BUILD='48.1'

ARCH=${ARCH:-i486}
CPU=${CPU:-i686}

CWD=`pwd`
TMP=$CWD/tgz
PKG=$TMP/package-$NAME

PACKAGE=$NAME-$VERSION-$ARCH-$BUILD

# prepare build directory
mkdir -p $PKG/install
mkdir -p $PKG/usr/{src,doc}/$NAME-$VERSION

# download source & patch
if [ ! -e  $NAME-$VERSION.tar.gz ]; then  wget $SOURCE_URL/$NAME-$VERSION.tar.gz; fi
if [ ! -e  $PATCH_FILE ]; then            wget $DOWNLOAD_URL/$PATCH_FILE; fi

# copy myself + patch
cp -a ${0} $PATCH_FILE $PKG/usr/src/$NAME-$VERSION

# Create the slack-desc and slack-required files, and copy the ZenBuild
#    |----handy-ruler------------------------------------------------------|
cat << EOF > $PKG/install/slack-desc
$NAME: id3lib (library for manipulating ID3v1 and ID3v2 tags)
$NAME:
$NAME: id3lib is an open-source, cross-platform software development
$NAME: library for reading, writing, and manipulating ID3v1 and ID3v2 tags.
$NAME: It is an on-going project whose primary goals are full compliance
$NAME: with the ID3v2 standard, portability across several platforms,
$NAME: and providing a powerful and feature-rich API with a highly stable
$NAME: and efficient implementation.
$NAME: 
$NAME: UTF16_writing_bug patch applied.
$NAME:
EOF

# Extract the source
cd $TMP
  tar xzf $CWD/$NAME-$VERSION.tar.gz

# Configure the package
cd $NAME-$VERSION
#  chown -R root:root .
  
# apply patch  
  patch -p1 < $CWD/$PATCH_FILE

# ./configure --help >$CWD/configure-id3lib

  CFLAGS="-O2 -march=$ARCH -mtune=$CPU" \
  CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU" \
  ./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --enable-debug=no \
    --enable-static=no
  
  make
  fakeroot make install DESTDIR=$PKG

# strip symbols
  find $PKG | xargs file | grep "executable" | grep ELF | cut -f 1 -d : |\
     xargs strip --strip-unneeded 2> /dev/null
     
  find $PKG | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : |\
     xargs strip --strip-unneeded 2> /dev/null

# copy standard docs
  cp -a AUTHORS COPYING README HISTORY ChangeLog TODO NEWS THANKS \
     $PKG/usr/doc/$NAME-$VERSION/

# more docs
  cp -r doc/{*.gif,*.jpg,*.png,*.txt,*.html,*.php} \
     $PKG/usr/doc/$NAME-$VERSION/

# wrong place doc dir     
  rm -rf $PKG/usr/doc/$NAME 2> /dev/null

cd $PKG
# find ./ -printf "%M %u:%g %p\n" > $CWD/files.raw
  fakeroot makepkg -l y -c n $CWD/$PACKAGE.tgz

cd $CWD
  requiredbuilder -z $PKG > $PACKAGE.dep
  md5sum $PACKAGE.tgz >$PACKAGE.md5

# cleanup
if [ "$1" = "--cleanup" ]; then
  rm -rf $TMP
fi

cat <<EOF >install-pkg.sh
#!/bin/sh
sudo upgradepkg --install-new $PACKAGE.tgz
EOF
chmod a+x ./install-pkg.sh
